%%
%% This is file `cp865.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp865')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2026
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{cp865.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textpeseta}{Pt}
\ProvideTextCommandDefault{\textblacksquare}
{\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\mathnsuperior}{{^n}}
\DeclareInputText{128}{\c C}
\DeclareInputText{129}{\"u}
\DeclareInputText{130}{\@tabacckludge'e}
\DeclareInputText{131}{\^a}
\DeclareInputText{132}{\"a}
\DeclareInputText{133}{\@tabacckludge`a}
\DeclareInputText{134}{\r a}
\DeclareInputText{135}{\c c}
\DeclareInputText{136}{\^e}
\DeclareInputText{137}{\"e}
\DeclareInputText{138}{\@tabacckludge`e}
\DeclareInputText{139}{\"\i}
\DeclareInputText{140}{\^\i}
\DeclareInputText{141}{\@tabacckludge`\i}
\DeclareInputText{142}{\"A}
\DeclareInputText{143}{\r A}
\DeclareInputText{144}{\@tabacckludge'E}
\DeclareInputText{145}{\ae}
\DeclareInputText{146}{\AE}
\DeclareInputText{147}{\^o}
\DeclareInputText{148}{\"o}
\DeclareInputText{149}{\@tabacckludge`o}
\DeclareInputText{150}{\^u}
\DeclareInputText{151}{\@tabacckludge`u}
\DeclareInputText{152}{\"y}
\DeclareInputText{153}{\"O}
\DeclareInputText{154}{\"U}
\DeclareInputText{155}{\o}
\DeclareInputText{156}{\pounds}
\DeclareInputText{157}{\O}
\DeclareInputText{158}{\textpeseta} % Pt
\DeclareInputText{159}{\textflorin}
\DeclareInputText{160}{\@tabacckludge'a} % 160
\DeclareInputText{161}{\@tabacckludge'\i}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{163}{\@tabacckludge'u}
\DeclareInputText{164}{\~n}
\DeclareInputText{165}{\~N}
\DeclareInputText{166}{\textordfeminine}
\DeclareInputText{167}{\textordmasculine}
\DeclareInputText{168}{\textquestiondown}
\DeclareInputMath{170}{\lnot}
\DeclareInputText{171}{\textonehalf}
\DeclareInputText{172}{\textonequarter}
\DeclareInputText{173}{\textexclamdown}
\DeclareInputText{174}{\guillemetleft}
\DeclareInputText{175}{\textcurrency}
\DeclareInputMath{224}{\alpha}
\DeclareInputMath{225}{\beta}
\DeclareInputMath{226}{\Gamma}
\DeclareInputMath{227}{\pi}
\DeclareInputMath{228}{\Sigma}
\DeclareInputMath{229}{\sigma}
\DeclareInputMath{230}{\mu}
\DeclareInputMath{231}{\gamma}
\DeclareInputMath{232}{\Phi}
\DeclareInputMath{233}{\theta}
\DeclareInputMath{234}{\Omega}
\DeclareInputMath{235}{\delta}
\DeclareInputMath{236}{\infty}
\DeclareInputMath{237}{\phi}
\DeclareInputMath{238}{\varepsilon}
\DeclareInputMath{239}{\cap}
\DeclareInputMath{240}{\equiv}
\DeclareInputMath{241}{\pm}
\DeclareInputMath{242}{\geq}
\DeclareInputMath{243}{\leq}
\DeclareInputMath{246}{\div}
\DeclareInputMath{247}{\approx}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textperiodcentered}
\DeclareInputText{250}{\textbullet}
\DeclareInputMath{251}{\surd}
\DeclareInputMath{252}{\mathnsuperior}
\DeclareInputMath{253}{\mathtwosuperior}
\DeclareInputText{254}{\textblacksquare} % right name?
\DeclareInputText{255}{\nobreakspace}
\endinput
%%
%% End of file `cp865.def'.
