%%
%% This is file `latex209.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% latex209.dtx  (with options: `head')
%% oldlfont.dtx  (with options: `latex209')
%% latex209.dtx  (with options: `tail')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2026
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{latex209.def}[2020/11/26 v0.55 Standard LaTeX file]
\if@compatibility
  \expandafter\endinput
\else
  \typeout{^^J\space
\@spaces\@spaces\space  Entering LaTeX 2.09 COMPATIBILITY MODE^^J\space
 *************************************************************^^J\space
 \space\space\space!!WARNING!!\space
 \space\space\space!!WARNING!!\space
 \space\space\space!!WARNING!!\space
 \space\space\space!!WARNING!!\space\space\space   ^^J\space
 ^^J\space
 This mode attempts to provide an emulation of the LaTeX 2.09^^J\space
 author environment so that OLD documents can be successfully^^J\space
 processed. It should NOT be used for NEW documents!^^J\space
 ^^J\space
 New documents should use Standard LaTeX conventions and start^^J\space
 with the \string\documentclass\space command.^^J\space
 ^^J\space
 Compatibility mode is UNLIKELY TO WORK with LaTeX 2.09 style^^J\space
 files that change any internal macros, especially not with^^J\space
 those that change the FONT SELECTION or OUTPUT ROUTINES.^^J\space
^^J\space
 Therefore such style files   MUST BE UPDATED to use^^J\space
\@spaces\@spaces\space        Current Standard LaTeX: LaTeX2e.^^J\space
 If you suspect that you may be using such a style file, which^^J\space
 is probably very, very old by now, then you should attempt to^^J\space
 get it updated by sending a copy of this error message to the^^J\space
 author of that file.^^J\space
 *************************************************************^^J}
 \fi
\@compatibilitytrue
\def\@tempa#1#2{%
   \expandafter\let\csname @@\string#1\endcsname#1%
   \edef#1{%
      \noexpand\@latex@e@error{\noexpand#2}%
      \expandafter\noexpand\csname @@\string#1\endcsname
   }%
}
\@tempa\usepackage\usepackage
\@tempa\listfiles\listfiles
\@tempa\ensuremath\ensuremath
\@tempa\lrbox{\begin{lrbox}}%
\@tempa\@xargdef{\newcommand{cmd}[args][def]}%
\let\@latex@e@error\@gobble
\def\@latex@e@error@#1{%
      \@latexerr{%
         LaTeX2e command \string#1\space in LaTeX 2.09 document%
      }{%
         This is a LaTeX 2.09 document, but it contains
         \string#1.^^J%
         If you want to use the new features of LaTeX2e,
         your document^^J%
         should begin with \string\documentclass\space
         rather than \string\documentstyle
      }%
}
\let\@old@ifdefinable\@ifdefinable
\long\def\@ifdefinable#1{%
   \def\@tempa##1#1##2#1##3#1##4\@tempa{%
      \def\@latex@e@commands{##1##2}%
      ##3% ##3 will either be \iftrue or \iffalse
         \expandafter\@firstofone
      \else
         \expandafter\@old@ifdefinable\expandafter#1%
      \fi
   }%
   \expandafter\@tempa\@latex@e@commands#1\iftrue#1\iffalse#1\@tempa%
}
\let\@@ifdefinable\@ifdefinable
\def\@latex@e@commands{%
   \usepackage\listfiles\ensuremath\LaTeXe\lrbox
   \th\dh\ng\dj\TH\DH\NG\DJ\k\r\SS
   \guillemetleft\guillemetright
   \guillemotleft\guillemotright\guilsinglleft
   \guilsinglright\quotedblbase\quotesinglbase
}
\def\@documentclasshook{%
  \RequirePackage\@unusedoptionlist
  \let\@unusedoptionlist\@empty
  \def\@tempa{\@normalsize}%
  \ifx\normalsize\@tempa
    \let\normalsize\@normalsize
  \fi
  \ifx\@normalsize\@undefined
    \let\@normalsize\normalsize
  \fi
  \ifx\normalsize\@undefined
    \let\normalsize\original@normalsize
  \fi
  \let\@latex@e@error\@latex@e@error@}
\let\original@normalsize\normalsize
\def\normalsize{\@normalsize}
\@ifundefined{saved@missingfileerror}{
   \let\saved@missingfileerror=\@missingfileerror
}{}
\def\@missingfileerror#1#2{%
   \ifx#2\@clsextension
      \InputIfFileExists{#1.\@pkgextension}{%
         \wlog{Compatibility mode: loading #1.\@pkgextension
            \space rather than #1.#2.}%
      }{%
         \saved@missingfileerror{#1}{#2}%
      }%
   \else
      \saved@missingfileerror{#1}{#2}%
   \fi
}
\@ifundefined{@missing@onefilewithoptions}{}{%
  \def\@missing@onefilewithoptions#1{%
    \@pass@ptions\@currext{#1}{\@currname}%
    \@missingfileerror\@currname\@currext
    \let\@currname\@empty}%
}
\def\@obsoletefile#1#2{%
   \expandafter\let\csname opt@#1\expandafter\endcsname
      \csname opt@\@currname.\@currext\endcsname
   \wlog{Compatibility mode: inputting `#1'
      instead of obsolete `#2'.}}
\newdimen\footheight
\newdimen\@maxsep
\newdimen\@dblmaxsep
\mark{{}{}}
\ExplSyntaxOn
\marks1{\__mark_value:nn {2.09-compat}{}}
\marks2{\__mark_value:nn {2.09-compat}{}}
\marks3{\__mark_value:nn {2.09-compat}{}}
\ExplSyntaxOff
\def\sloppy{\tolerance \@M \hfuzz .5\p@ \vfuzz .5\p@}
\def\@finalstrut#1{\unskip\strut}
\let \@marginparreset \@empty
\let \@floatboxreset \@empty
\outer\def\proclaim #1. #2\par{%
  \medbreak
  \noindent{\bfseries#1.\enspace}{\slshape#2\par}%
  \ifdim\lastskip<\medskipamount
    \removelastskip\penalty55\medskip
  \fi}
\def\hang{\hangindent\parindent}
\def\textindent#1{\indent\llap{#1\enspace}\ignorespaces}
\def\ttraggedright{\reset@font\ttfamily\rightskip\z@ plus2em\relax}
\def\@footnotemark{%
  \leavevmode
  \ifhmode\edef\@x@sf{\the\spacefactor}\fi
  \@makefnmark
  \ifhmode\spacefactor\@x@sf\fi
  \relax}
\def\@textsuperscript#1{$\m@th^{\@gobble#1}$}
\def\@makefnmark{\hbox{$^{\@thefnmark}\m@th$}}
\def\thempfootnote{\@alph\c@mpfootnote}
\def\@fnsymbol#1{\ifcase#1\or *\or \dagger\or \ddagger\or
    \mathchar "278\or \mathchar "27B\or \|\or **\or \dagger\dagger
    \or \ddagger\ddagger \else\@ctrerr\fi}
\let\@inmathwarn\@gobble
\def\verb{%
   \relax\ifmmode\hbox\fi\bgroup
      \@noligs
      \verbatim@font
      \let\do\@makeother \dospecials
      \@ifstar{\@sverb}{\@verb}%
}
\def\@sverb#1{%
   \def\@tempa ##1#1{\leavevmode\null##1\egroup}%
   \@tempa
}
\def\verbatim@nolig@list{\do\`}
\def\@lquote{\leavevmode{\kern\z@}`}
\catcode0=9
\@tempcnta=1
\loop\ifnum\@tempcnta<32
   \catcode\@tempcnta=12
   \advance\@tempcnta by 1
\repeat%
\catcode`\^^I=10\relax%
\catcode`\^^L=13\relax%
\catcode`\^^M=5\relax%
\catcode127=15
\@tempcnta=128
\loop\ifnum\@tempcnta<256
   \catcode\@tempcnta=12
   \advance\@tempcnta by 1
\repeat
\DeclareRobustCommand{\SLiTeX}{{%
   \normalfont S\kern -.06em
   {\scshape l\kern -.035emi}\kern -.06em
   \TeX}}
\let\+\@empty
\newcount\@cla
\newcount\@clb
\newcount\mscount
\long\def\@imakepicbox(#1,#2)[#3]#4{%
  \vbox to#2\unitlength
   {\let\mb@b\vss \let\mb@l\hss\let\mb@r\hss
    \let\mb@t\vss
    \@tfor\reserved@a :=#3\do{%
      \if s\reserved@a
        \let\mb@l\relax\let\mb@r\relax
      \else
        \expandafter\let\csname mb@\reserved@a\endcsname\relax
      \fi}%
    \mb@t
    \hb@xt@ #1\unitlength{\mb@l #4\mb@r}%
    \mb@b
     }}
\def\supereject{\par\penalty-\@MM}
\def\nofiles{%
  \@fileswfalse
  \typeout{No auxiliary output files.^^J}%
  \long\def\protected@write##1##2##3{}%
  \let\makeindex\relax
  \let\makeglossary\relax}
\def\ProvidesPackage#1{%
  \xdef\@gtempa{#1}%
  \ifx\@gtempa\@currname\else
    \wlog{Compatibility mode: \@cls@pkg\space`\@currname' requested,
       but `#1' provided.}%
  \fi
  \@ifnextchar[\@pr@videpackage{\@pr@videpackage[]}}%]
\let\ProvidesClass=\ProvidesPackage
%% File `oldlfont.dtx'.
%% Copyright (C) 1989-1995 Frank Mittelbach and Rainer Sch\"opf,
%% all rights reserved.
\let\math@bgroup\@empty
\let\math@egroup\@empty
\let \@@math@bgroup \math@bgroup
\let \@@math@egroup \math@egroup
\RequirePackage[errorshow]{tracefnt}
\DeclareSymbolFont{bold}{OT1}{cmr}{bx}{n}
\DeclareSymbolFont{sans}{OT1}{cmss}{m}{n}
\DeclareSymbolFont{typewriter}{OT1}{cmtt}{m}{n}
\DeclareSymbolFont{italic}{OT1}{cmr}{m}{it}
\DeclareSymbolFont{smallcaps}{OT1}{cmr}{m}{sc}
\DeclareSymbolFont{slanted}{OT1}{cmr}{m}{sl}
\DeclareSymbolFontAlphabet\mathbf{bold}
\DeclareSymbolFontAlphabet\mathsf{sans}
\DeclareSymbolFontAlphabet\mathtt{typewriter}
\DeclareSymbolFontAlphabet\mathsc{smallcaps}
\DeclareSymbolFontAlphabet\mathsl{slanted}
\let\mit\undefined
\let\cal\undefined
\let\mathit\undefined
\DeclareSymbolFontAlphabet\mathit{italic}
\DeclareSymbolFontAlphabet{\mit}{letters}
\DeclareSymbolFontAlphabet{\cal}{symbols}
\DeclareRobustCommand\rm{\normalfont\rmfamily\mathgroup\symoperators}
\DeclareRobustCommand\sf{\normalfont\sffamily\mathgroup\symsans}
\DeclareRobustCommand\sl{\normalfont\slshape\mathgroup\symslanted}
\DeclareRobustCommand\bf{\normalfont\bfseries\mathgroup\symbold}
\DeclareRobustCommand\sc{\normalfont\scshape\mathgroup\symsmallcaps}
\DeclareRobustCommand\it{\normalfont\itshape\mathgroup\symitalic}
\DeclareRobustCommand\tt{\normalfont\ttfamily\mathgroup\symtypewriter}
\DeclareRobustCommand\em{%
  \@nomath\em
  \ifdim \fontdimen\@ne\font>\z@\rm\else\it\fi}
\def\@setfontsize#1#2#3{\@nomath#1%
    \ifx\protect\@typeset@protect
      \let\@currsize#1%
    \fi
    \fontsize{#2}{#3}\normalfont}
\let\not@math@alphabet\@gobbletwo
\RequirePackage{latexsym}
\def\ds@oldlfont{%
   \let\math@bgroup\@empty
   \let\math@egroup\@empty
   \let\@@math@bgroup\math@bgroup
   \let\@@math@egroup\math@egroup
}
\def\ds@newlfont{%
   \OptionNotUsed
}
\def\ds@margid{%
  \let\math@bgroup\bgroup
  \def\math@egroup##1{##1\egroup}%
  \let \@@math@bgroup \math@bgroup
  \let \@@math@egroup \math@egroup
}
\let\ds@nomargid\ds@oldlfont
\@onlypreamble\ds@oldfont
\@onlypreamble\ds@newfont
\@onlypreamble\ds@margid
\@onlypreamble\ds@nomargid
\renewcommand{\encodingdefault}{OT1}
\expandafter\font\csname cmex/m/n/10\endcsname=cmex10
\def\normalshape{\fontshape\shapedefault\selectfont}
\def\mediumseries{\fontseries\seriesdefault\selectfont}
\def \DeclareOldFontCommand #1#2#3{%
  \wlog{Compatibility mode: definition
        of \string#1\space ignored.}%
}
\def\@halfmag{ scaled \magstephalf}
\def\@magscale#1{ scaled \magstep#1 }
\def\@ptscale#1{ scaled #100 }
\fontencoding{OT1} \fontfamily{cmr}
\fontsize{10}{12} \fontseries{m} \fontshape{n}
\selectfont
\let\load\@gobbletwo
\DeclareMathDelimiter{\lgroup} % extensible ( with sharper tips
     {\mathopen}{bold}{"28}{largesymbols}{"3A}
\DeclareMathDelimiter{\rgroup} % extensible ) with sharper tips
     {\mathclose}{bold}{"29}{largesymbols}{"3B}
\DeclareMathDelimiter{\bracevert} % the vertical bar that extends braces
     {\mathord}{typewriter}{"7C}{largesymbols}{"3E}
\let\bffam\symbold
\let\sffam\symsans
\let\itfam\symitalic
\let\ttfam\symtypewriter
\let\scfam\symsmallcaps
\let\slfam\symslanted
\let\rmfam\symoperators
\newcommand\vpt   {\edef\f@size{\@vpt}\rm}
\newcommand\vipt  {\edef\f@size{\@vipt}\rm}
\newcommand\viipt {\edef\f@size{\@viipt}\rm}
\newcommand\viiipt{\edef\f@size{\@viiipt}\rm}
\newcommand\ixpt  {\edef\f@size{\@ixpt}\rm}
\newcommand\xpt   {\edef\f@size{\@xpt}\rm}
\newcommand\xipt  {\edef\f@size{\@xipt}\rm}
\newcommand\xiipt {\edef\f@size{\@xiipt}\rm}
\newcommand\xivpt {\edef\f@size{\@xivpt}\rm}
\newcommand\xviipt{\edef\f@size{\@xviipt}\rm}
\newcommand\xxpt  {\edef\f@size{\@xxpt}\rm}
\newcommand\xxvpt {\edef\f@size{\@xxvpt}\rm}
\InputIfFileExists{latex209.cfg}{}{}
\endinput
%%
%% End of file `latex209.def'.
