%%
%% This is file `applemac.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `applemac')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2026
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{applemac.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\DeclareInputText{128}{\"A}
\DeclareInputText{129}{\r A}
\DeclareInputText{130}{\c C}
\DeclareInputText{131}{\@tabacckludge'E}
\DeclareInputText{132}{\~N}
\DeclareInputText{133}{\"O}
\DeclareInputText{134}{\"U}
\DeclareInputText{135}{\@tabacckludge'a}
\DeclareInputText{136}{\@tabacckludge`a}
\DeclareInputText{137}{\^a}
\DeclareInputText{138}{\"a}
\DeclareInputText{139}{\~a}
\DeclareInputText{140}{\r a}
\DeclareInputText{141}{\c c}
\DeclareInputText{142}{\@tabacckludge'e}
\DeclareInputText{143}{\@tabacckludge`e}
\DeclareInputText{144}{\^e}
\DeclareInputText{145}{\"e}
\DeclareInputText{146}{\@tabacckludge'\i}
\DeclareInputText{147}{\@tabacckludge`\i}
\DeclareInputText{148}{\^\i}
\DeclareInputText{149}{\"\i}
\DeclareInputText{150}{\~n}
\DeclareInputText{151}{\@tabacckludge'o}
\DeclareInputText{152}{\@tabacckludge`o}
\DeclareInputText{153}{\^o}
\DeclareInputText{154}{\"o}
\DeclareInputText{155}{\~o}
\DeclareInputText{156}{\@tabacckludge'u}
\DeclareInputText{157}{\@tabacckludge`u}
\DeclareInputText{158}{\^u}
\DeclareInputText{159}{\"u}
\DeclareInputText{160}{\dag}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\S}
\DeclareInputText{165}{\textbullet}
\DeclareInputText{166}{\P}
\DeclareInputText{167}{\ss}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{\texttrademark}
\DeclareInputText{171}{\@tabacckludge'{}}
\DeclareInputText{172}{\"{}}
\DeclareInputMath{173}{\neq}
\DeclareInputText{174}{\AE}
\DeclareInputText{175}{\O}
\DeclareInputMath{176}{\infty}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{178}{\leq}
\DeclareInputMath{179}{\geq}
\DeclareInputText{180}{\textyen}
\DeclareInputMath{181}{\mu}
\DeclareInputMath{182}{\partial}
\DeclareInputMath{183}{\Sigma}
\DeclareInputMath{184}{\Pi}
\DeclareInputMath{185}{\pi}
\DeclareInputMath{186}{\int}
\DeclareInputText{187}{\textordfeminine}
\DeclareInputText{188}{\textordmasculine}
\DeclareInputMath{189}{\Omega}
\DeclareInputText{190}{\ae}
\DeclareInputText{191}{\o}
\DeclareInputText{192}{\textquestiondown}
\DeclareInputText{193}{\textexclamdown}
\DeclareInputMath{194}{\lnot}
\DeclareInputMath{195}{\surd}
\DeclareInputText{196}{\textflorin}
\DeclareInputMath{197}{\approx}
\DeclareInputMath{198}{\Delta}
\DeclareInputText{199}{\guillemetleft}
\DeclareInputText{200}{\guillemetright}
\DeclareInputText{201}{\dots}
\DeclareInputText{202}{\nobreakspace}
\DeclareInputText{203}{\@tabacckludge`A}
\DeclareInputText{204}{\~A}
\DeclareInputText{205}{\~O}
\DeclareInputText{206}{\OE}
\DeclareInputText{207}{\oe}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputMath{214}{\div}
\DeclareInputMath{215}{\diamond}
\DeclareInputText{216}{\"y}
\DeclareInputText{217}{\"Y}
\DeclareInputMath{218}{/}
\DeclareInputText{219}{\textcurrency}
\DeclareInputText{220}{\guilsinglleft}
\DeclareInputText{221}{\guilsinglright}
\DeclareInputText{222}{fi}
\DeclareInputText{223}{fl}
\DeclareInputText{224}{\ddag}
\DeclareInputText{225}{\textperiodcentered}
\DeclareInputText{226}{\quotesinglbase}
\DeclareInputText{227}{\quotedblbase}
\DeclareInputText{228}{\textperthousand}
\DeclareInputText{229}{\^A}
\DeclareInputText{230}{\^E}
\DeclareInputText{231}{\@tabacckludge'A}
\DeclareInputText{232}{\"E}
\DeclareInputText{233}{\@tabacckludge`E}
\DeclareInputText{234}{\@tabacckludge'I}
\DeclareInputText{235}{\^I}
\DeclareInputText{236}{\"I}
\DeclareInputText{237}{\@tabacckludge`I}
\DeclareInputText{238}{\@tabacckludge'O}
\DeclareInputText{239}{\^O}
\DeclareInputText{240}{\textapplelogo}
\DeclareInputText{241}{\@tabacckludge`O}
\DeclareInputText{242}{\@tabacckludge'U}
\DeclareInputText{243}{\^U}
\DeclareInputText{244}{\@tabacckludge`U}
\DeclareInputText{245}{\i}
\DeclareInputText{246}{\^{}}
\DeclareInputText{247}{\~{}}
\DeclareInputText{248}{\@tabacckludge={}}
\DeclareInputText{249}{\u{}}
\DeclareInputText{250}{\.{}}
\DeclareInputText{251}{\r{}}
\DeclareInputText{252}{\c\ }
\DeclareInputText{253}{\H{}}
\DeclareInputText{254}{\k\ }
\DeclareInputText{255}{\v{}}
\endinput
%%
%% End of file `applemac.def'.
